@@ -36,7 +36,14 @@ def mock_run_command(command_output, create_dir=None):
 class TestContext(main.Context):
     def _normalize_path(self, unnorm_path):
         return super(TestContext, self)._normalize_path(topdir)
+    
+    def reset(self):
+        self.output.truncate(0)
+        try:
+            del self.output.return_code
+        except AttributeError:
+            pass
 
-test_context = TestContext(topdir)
+test_context = TestContext(topdir, output=main.IOWrapper(StringIO()))
 
 
